==> openshift-model-operatorhub-4.11.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/BundleLookupFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface BundleLookupFluent<A extends BundleLookupFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildCatalogSourceRef instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getCatalogSourceRef();
    public ObjectReference buildCatalogSourceRef();
    public A withCatalogSourceRef(ObjectReference catalogSourceRef);
    public Boolean hasCatalogSourceRef();
    public BundleLookupFluent.CatalogSourceRefNested<A> withNewCatalogSourceRef();
    public BundleLookupFluent.CatalogSourceRefNested<A> withNewCatalogSourceRefLike(ObjectReference item);
    public BundleLookupFluent.CatalogSourceRefNested<A> editCatalogSourceRef();
    public BundleLookupFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRef();
    public BundleLookupFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRefLike(ObjectReference item);
    public A addToConditions(int index,BundleLookupCondition item);
    public A setToConditions(int index,BundleLookupCondition item);
    public A addToConditions(BundleLookupCondition... items);
    public A addAllToConditions(Collection<BundleLookupCondition> items);
    public A removeFromConditions(BundleLookupCondition... items);
    public A removeAllFromConditions(Collection<BundleLookupCondition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<BundleLookupConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<BundleLookupCondition> getConditions();
    public List<BundleLookupCondition> buildConditions();
    public BundleLookupCondition buildCondition(int index);
    public BundleLookupCondition buildFirstCondition();
    public BundleLookupCondition buildLastCondition();
    public BundleLookupCondition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<BundleLookupConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<BundleLookupConditionBuilder> predicate);
    public A withConditions(List<BundleLookupCondition> conditions);
    public A withConditions(BundleLookupCondition... conditions);
    public Boolean hasConditions();
    public BundleLookupFluent.ConditionsNested<A> addNewCondition();
    public BundleLookupFluent.ConditionsNested<A> addNewConditionLike(BundleLookupCondition item);
    public BundleLookupFluent.ConditionsNested<A> setNewConditionLike(int index,BundleLookupCondition item);
    public BundleLookupFluent.ConditionsNested<A> editCondition(int index);
    public BundleLookupFluent.ConditionsNested<A> editFirstCondition();
    public BundleLookupFluent.ConditionsNested<A> editLastCondition();
    public BundleLookupFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<BundleLookupConditionBuilder> predicate);
    public String getIdentifier();
    public A withIdentifier(String identifier);
    public Boolean hasIdentifier();
    public A withNewIdentifier(String arg1);
    public A withNewIdentifier(StringBuilder arg1);
    public A withNewIdentifier(StringBuffer arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);
    public String getReplaces();
    public A withReplaces(String replaces);
    public Boolean hasReplaces();
    public A withNewReplaces(String arg1);
    public A withNewReplaces(StringBuilder arg1);
    public A withNewReplaces(StringBuffer arg1);

    public interface CatalogSourceRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<BundleLookupFluent.CatalogSourceRefNested<N>>{

        
    public N and();    public N endCatalogSourceRef();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BundleLookupConditionFluent<BundleLookupFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}

==> openshift-model-operatorhub-5.2.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/BundleLookupFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface BundleLookupFluent<A extends BundleLookupFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCatalogSourceRef instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getCatalogSourceRef();
    public ObjectReference buildCatalogSourceRef();
    public A withCatalogSourceRef(ObjectReference catalogSourceRef);
    public Boolean hasCatalogSourceRef();
    public BundleLookupFluent.CatalogSourceRefNested<A> withNewCatalogSourceRef();
    public BundleLookupFluent.CatalogSourceRefNested<A> withNewCatalogSourceRefLike(ObjectReference item);
    public BundleLookupFluent.CatalogSourceRefNested<A> editCatalogSourceRef();
    public BundleLookupFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRef();
    public BundleLookupFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRefLike(ObjectReference item);
    public A addToConditions(int index,BundleLookupCondition item);
    public A setToConditions(int index,BundleLookupCondition item);
    public A addToConditions(BundleLookupCondition... items);
    public A addAllToConditions(Collection<BundleLookupCondition> items);
    public A removeFromConditions(BundleLookupCondition... items);
    public A removeAllFromConditions(Collection<BundleLookupCondition> items);
    public A removeMatchingFromConditions(Predicate<BundleLookupConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<BundleLookupCondition> getConditions();
    public List<BundleLookupCondition> buildConditions();
    public BundleLookupCondition buildCondition(int index);
    public BundleLookupCondition buildFirstCondition();
    public BundleLookupCondition buildLastCondition();
    public BundleLookupCondition buildMatchingCondition(Predicate<BundleLookupConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<BundleLookupConditionBuilder> predicate);
    public A withConditions(List<BundleLookupCondition> conditions);
    public A withConditions(BundleLookupCondition... conditions);
    public Boolean hasConditions();
    public BundleLookupFluent.ConditionsNested<A> addNewCondition();
    public BundleLookupFluent.ConditionsNested<A> addNewConditionLike(BundleLookupCondition item);
    public BundleLookupFluent.ConditionsNested<A> setNewConditionLike(int index,BundleLookupCondition item);
    public BundleLookupFluent.ConditionsNested<A> editCondition(int index);
    public BundleLookupFluent.ConditionsNested<A> editFirstCondition();
    public BundleLookupFluent.ConditionsNested<A> editLastCondition();
    public BundleLookupFluent.ConditionsNested<A> editMatchingCondition(Predicate<BundleLookupConditionBuilder> predicate);
    public String getIdentifier();
    public A withIdentifier(String identifier);
    public Boolean hasIdentifier();
    public A withNewIdentifier(String arg1);
    public A withNewIdentifier(StringBuilder arg1);
    public A withNewIdentifier(StringBuffer arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);
    public String getReplaces();
    public A withReplaces(String replaces);
    public Boolean hasReplaces();
    public A withNewReplaces(String arg1);
    public A withNewReplaces(StringBuilder arg1);
    public A withNewReplaces(StringBuffer arg1);
    public interface CatalogSourceRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<BundleLookupFluent.CatalogSourceRefNested<N>> {

            public N and();
            public N endCatalogSourceRef();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BundleLookupConditionFluent<BundleLookupFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


}
